# Design tokens and theming for Smarty UI

## Design tokens

Design tokens are the foundation of the design system. They are the building blocks of the design system.

## Theming

Theming is the process of applying a theme to a design system.

theme.py --- theme dataclass that bundles tokens.